import React, { useState, useEffect, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import DetailPro from '@/components/DetailPro';
import useKeepAlive from "@/components/useKeepAlive";
import getcolumns from "./columns";

const columnsa = [
  {
    title: "物料编号-名称",
    dataIndex: "name",
    key: "name",
    render: (_, row) => {
      return (
        <span className='table-cell'>{row?.materialCode}-{row?.materialName}</span>
      );
    },
  },
  {
    title: "工单号",
    dataIndex: "jobNo",
    key: "jobNo",
  },
  {
    title: "入库数量",
    dataIndex: "inStoreNum",
    key: "inStoreNum",
  },
  {
    title: "库存单位",
    dataIndex: "productionUnitName",
    key: "productionUnitName",
  },
  {
    title: "未上架数量",
    dataIndex: "notUploadNum",
    key: "notUploadNum",
  }
],
  columnsb = [
    {
      title: "库位名称",
      dataIndex: "storePositionName",
      key: "storePositionName",
    },
    {
      title: "计划数量",
      dataIndex: "planNum",
      key: "planNum",
    },
    {
      title: "上架数量",
      dataIndex: "inStoreNum",
      key: "inStoreNum",
    },
    {
      title: "状态",
      dataIndex: "statusName",
      key: "statusName",
    },
  ];
function Manage() {
  let actionRef = useRef();
  const [drawer, setdrawer] = useState({
    open: false,
  }),
    [tabKey, setTabKey] = useState('1');
  const tabList = useMemo(() => {
    return getcolumns();
  }, [tabKey]);
  const columns = useMemo(() => {
    let defcolumn = getcolumns(setdrawer).filter((it) => it.key == tabKey)[0]?.columns ?? [];
    return defcolumn;
  }, [tabKey]);
  const pathconfig = useMemo(() => {
    let defpath = getcolumns(setdrawer).filter((it) => it.key == tabKey)[0]?.pathconfig ?? {};
    return defpath;
  }, [tabKey]);




  return <div>
    <AutoTable
      pagetitle='入库单管理'
      columns={columns}
      path={drawer?.open ? null : pathconfig?.list}
      actionRef={actionRef}
      resizeable={false}
      tabList={tabList}
      tabKey={tabKey}
      onTabChange={(key) => {
        setTabKey(key);
      }}
    />
    <DrawerPro
      {...drawer}
      fields={columns}
      detailData={drawer?.item}
      placement="right"
      onClose={() => {
        setdrawer((s) => ({
          ...s,
          open: false,
        }));
      }}
    >
      <div className='splittitle' style={{ borderWidth: 1, marginBottom: 16 }}>物料信息</div>
      <AutoTable
        columns={columnsa}
        withCard={false}
        pagination={false}
        expandable={{
          expandedRowRender: (record) => (
            <AutoTable
              withCard={false}
              pagination={false}
              className="expandableTable"
              columns={columnsb}
              dataSource={record?.uploadList ?? []}
            />
          )
        }}
        dataSource={drawer?.item?.detailList ?? []}
        defaultExpandAllRows
        style={{marginBottom:16}}
      />
      {
        tabKey === '2' && <DetailPro
          fields={[
            { title: "强制关单信息", valueType: "split" },
            { title: "关单人员", dataIndex: "closeUserName" },
            { title: "关单时间", dataIndex: "closeTime" },
          ]}
          detailData={drawer?.item}
        />
      }
    </DrawerPro>
  </div>
}

export default useKeepAlive(Manage);